@@ -1,4 +1,7 @@
-setOldClass(c("hms", "difftime"))
+setMethod("asJSON", "ts", function(x, ...) {
+  asJSON(as.vector(x), ...)
+})
+
 setMethod("asJSON", "hms", function(x, hms = c("string", "secs"), ...) {
   hms <- match.arg(hms)
   output <- switch(hms,
