@@ -1,4 +1,4 @@
-context("fromJSON Matrix")
+
 
 # Note about numeric precision
 # In the unit tests we use digits=10. Lowever values will result in problems for some datasets
@@ -15,18 +15,18 @@ test_that("fromJSON Matrix", {
 
   lapply(objects, function(object){
     newobject <- fromJSON(toJSON(object));
-    expect_that(newobject, is_a("matrix"));
-    expect_that(object, equals(newobject));
+    expect_true(inherits(newobject, "matrix"));
+    expect_equal(object, newobject);
   });
 
-  expect_that(fromJSON(toJSON(objects)), equals(objects));
+  expect_equal(fromJSON(toJSON(objects)), objects);
 });
 
 test_that("fromJSON Matrix with simplifyMatrix=FALSE", {
-  expect_that(fromJSON(toJSON(matrix(1)), simplifyMatrix=FALSE), equals(list(1)));
-  expect_that(fromJSON(toJSON(matrix(1)), simplifyVector=FALSE), equals(list(list((1)))));
-  expect_that(fromJSON(toJSON(matrix(NA)), simplifyMatrix=FALSE), equals(list(NA)));
-  expect_that(fromJSON(toJSON(matrix(NA)), simplifyVector=FALSE), equals(list(list((NULL)))));
+  expect_equal(fromJSON(toJSON(matrix(1)), simplifyMatrix=FALSE), list(1));
+  expect_equal(fromJSON(toJSON(matrix(1)), simplifyVector=FALSE), list(list((1))));
+  expect_equal(fromJSON(toJSON(matrix(NA)), simplifyMatrix=FALSE), list(NA));
+  expect_equal(fromJSON(toJSON(matrix(NA)), simplifyVector=FALSE), list(list((NULL))));
 });
 
 
@@ -36,12 +36,12 @@ test_that("fromJSON Matrix datasets", {
   lapply(objects, function(object){
     class(object) <- "matrix";
     newobject <- fromJSON(toJSON(object, digits=4))
-    expect_that(newobject, is_a("matrix"));
-    expect_that(dim(newobject), equals(dim(object)));
+    expect_true(inherits(newobject, "matrix"));
+    expect_equal(dim(newobject), dim(object));
     attributes(newobject) <- attributes(object);
 
     # R has changed rounding algo in 4.0 and no longer matches printf
-    #expect_that(newobject, equals(round(object,4)))
+    #expect_equal(newobject, round(object,4));
     expect_equal(newobject, object, tolerance = 1e-4)
   });
 });
